@@ -371,7 +371,7 @@ Ganglia_udp_send_channels_create( Ganglia_pool p, Ganglia_gmond_config config )
           socket = create_udp_client( pool, host, port, mcast_if, bind_address, bind_hostname );
           if(!socket)
             {
-              err_msg("Unable to create UDP client for %s:%d. Exiting.\n",
+              err_msg("Unable to create UDP client for %s:%d. Often means there is no route to IP. Exiting.\n",
                       host? host: "NULL", port);
               exit(1);
             }
@@ -640,7 +640,7 @@ Ganglia_metric_set( Ganglia_metric gmetric, char *name, char *value, char *type,
   apr_pool_t *gm_pool;
 
   /* Make sure all the params look ok */
-  if(!gmetric||!name||!value||!type||!units||slope>4)
+  if(!gmetric||!name||!value||!type||!units||slope>GANGLIA_SLOPE_LAST_LEGAL_VALUE)
     return 1;
 
   gm_pool = (apr_pool_t*)gmetric->pool;
