@@ -318,7 +318,6 @@ void update_ifdata ( char *caller )
         l_pin = l_pkts_in / t;
         l_pout = l_pkts_out / t;
 
-#ifdef REMOVE_BOGUS_SPIKES
         /*
          * Check for "invalid" data, caused by HW error. Throw away dubious data points
          * FIXME: This should be done per-interface, with threshholds depending on actual link speed
@@ -329,7 +328,6 @@ void update_ifdata ( char *caller )
                    l_bin, l_bout, l_pin, l_pout, t);
            return;
         }
-#endif
 
         /*
          * Finally return Values
@@ -877,7 +875,7 @@ cpu_aidle_func ( void )
    idle_jiffies  = (JT) strtod( p , (char **)NULL );
    total_jiffies = total_jiffies_func();
 
-   val.f = ((double)(idle_jiffies/total_jiffies)) * 100.0;
+   val.f = ((double)idle_jiffies/(double)total_jiffies) * 100.0;
 
    val.f = sanityCheck( __LINE__, __FILE__, __FUNCTION__, val.f, (double)idle_jiffies, (double)total_jiffies, idle_jiffies, total_jiffies, 0, 0 );
    return val;
